'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// Palenight theme color definitions
const base00 = '#292D3E', // Background
base01 = '#A6ACCD', // Foreground
base02 = '#444267', // Darker selection match
base03 = '#676E95', // Comments
base04 = '#A6ACCD', // Cursor color
base05 = '#C3E88D', // Green for strings and regex
base06 = '#33374D', // Line highlight
base07 = '#82AAFF', // Blue for keywords, type names, and operators
base08 = '#F78C6C'; // Orange for numbers, headings, and constants
const invalid = '#FF5370', // Red for invalid elements
darkBackground = base00, highlightBackground = base06, background = base00, // Main background
tooltipBackground = '#444267', selection = '#444267', cursor = base04; // Cursor color
// The editor theme styles for Palenight
const palenightTheme = view.EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: background,
    },
    '.cm-content': {
        caretColor: cursor,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base03,
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground,
    },
    '.cm-selectionMatch': {
        backgroundColor: base02,
    },
    '&.cm-focused .cm-matchingBracket': {
        backgroundColor: highlightBackground,
    },
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base03,
        border: 'none',
    },
    '.cm-tooltip': {
        backgroundColor: tooltipBackground,
    },
}, { dark: true });
// The highlighting style for Palenight
const palenightHighlightStyle = language.HighlightStyle.define([
    { tag: highlight.tags.keyword, color: base07 },
    { tag: [highlight.tags.name, highlight.tags.deleted, highlight.tags.character, highlight.tags.macroName], color: base01 },
    { tag: [highlight.tags.propertyName], color: base01 },
    {
        tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted, highlight.tags.special(highlight.tags.string)],
        color: base05,
    },
    { tag: [highlight.tags.function(highlight.tags.variableName), highlight.tags.labelName], color: base01 },
    { tag: [highlight.tags.color, highlight.tags.constant(highlight.tags.name), highlight.tags.standard(highlight.tags.name)], color: base01 },
    { tag: [highlight.tags.definition(highlight.tags.name), highlight.tags.separator], color: base01 },
    { tag: [highlight.tags.className], color: base01 },
    {
        tag: [highlight.tags.number, highlight.tags.changed, highlight.tags.annotation, highlight.tags.modifier, highlight.tags.self, highlight.tags.namespace],
        color: base08,
    },
    { tag: [highlight.tags.typeName], color: base07 },
    { tag: [highlight.tags.operator, highlight.tags.operatorKeyword], color: base07 },
    { tag: [highlight.tags.url, highlight.tags.escape, highlight.tags.regexp, highlight.tags.link], color: base05 },
    { tag: [highlight.tags.meta, highlight.tags.comment], color: base03 },
    { tag: highlight.tags.tagName, color: base07 },
    { tag: highlight.tags.strong, fontWeight: 'bold' },
    { tag: highlight.tags.emphasis, fontStyle: 'italic' },
    { tag: highlight.tags.link, textDecoration: 'underline' },
    { tag: highlight.tags.heading, fontWeight: 'bold', color: base08 },
    { tag: [highlight.tags.atom, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)], color: base01 },
    { tag: highlight.tags.invalid, color: invalid },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' },
]);
// Extension to enable the Palenight theme (both editor theme and highlight style)
const palenight = [
    palenightTheme,
    language.syntaxHighlighting(palenightHighlightStyle),
];

exports.palenight = palenight;
exports.palenightHighlightStyle = palenightHighlightStyle;
exports.palenightTheme = palenightTheme;
